==> haskell-distributive-0.6.2.1-322-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-59l4KP37X0m9badbOMWOqI
key:                  distributive-0.6.2.1-59l4KP37X0m9badbOMWOqI
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  55ed779a20f57485cf783b15622bb1cb
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.2.1-59l4KP37X0m9badbOMWOqI
depends:
    base-4.17.2.1 base-orphans-0.9.3-6taZvU9QCojGr5dAKf6AFZ
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6.2.1-324-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-9AhXrTOAPC0Fu5dlfo3GXW
key:                  distributive-0.6.2.1-9AhXrTOAPC0Fu5dlfo3GXW
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  6594ebfa5301f47b7bf7c0f61e9bb3d8
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.2.1-9AhXrTOAPC0Fu5dlfo3GXW
depends:
    base-4.17.2.1 base-orphans-0.9.3-3DLkOAXKQNd78v859McI2X
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
